'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
/**
 * Плагин для управления токена Laravel Passport.
 */
var VuePassportToken = {
    /**
     * Инъекция плагина.
     * 
     * @param {*} Vue Vue.js
     * @param {*} options Дополнительные параметры.
     */
    install: function install(Vue, options) {
        var _this = this;

        Vue.mixin({
            mounted: function mounted() {
                if (!window.wasLoaded) {
                    window.wasLoaded = true;
                    console.log('Laravel passport-tokens plugin was loaded!');
                }
            }
        });
        /**
         * Расширяем Vue методом $auth для доступа к функционалу управления токенами.
         *
         * @type {{setToken(string, int, string=): boolean, isAuthenticated: function(): (boolean|*), getToken: function(): (string | null), tokenWasExpired(): *, removeTokens(): void}}
         */
        Vue.prototype.$auth = {

            /**
             * Установка токенов.
             * 
             * @param {string} access_token 
             * @param {int} expires_in 
             * @param {string} refresh_token 
             */
            setToken: function setToken(access_token, expires_in) {
                var refresh_token = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : undefined;


                if (access_token === undefined || access_token.length < 1) {
                    console.warn('\u0412\u043D\u0438\u043C\u0430\u043D\u0438\u0435! \u041D\u0435 \u0443\u0434\u0430\u043B\u043E\u0441\u044C \u0443\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C \u0442\u043E\u043A\u0435\u043D: ' + access_token + ', \u0442.\u043A. \u043E\u043D \u043D\u0435 \u0437\u0430\u0434\u0430\u043D \u0438\u043B\u0438 \u043F\u0443\u0441\u0442!');
                    return false;
                }

                localStorage.setItem('access_token', access_token);

                if (expires_in !== undefined) {
                    localStorage.setItem('expires_in', expires_in + new Date());
                }

                if (refresh_token !== undefined) {
                    localStorage.setItem('refresh_token', refresh_token);
                }

                return true;
            },

            /**
             * Проверить авторизованность (наличие установленного токена и время его жизни).
             */
            isAuthenticated: function isAuthenticated() {
                return !_this.tokenWasExpired() && _this.getToken();
            },

            /**
             * Получить токен доступа.
             */
            getToken: function getToken() {
                return localStorage.getItem('access_token');
            },

            /**
             * Проверить, истекло ли время жизни токена.
             */
            tokenWasExpired: function tokenWasExpired() {
                var expires_in = localStorage.getItem('expires_in');

                return !expires_in ? false : new Date() >= expires_in;
            },

            /**
             * Удалить токены из хранилища.
             */
            removeTokens: function removeTokens() {
                localStorage.removeItem('access_token');
                localStorage.removeItem('expires_in');
                localStorage.removeItem('refresh_token');
            }
        };
    }
};

exports.default = VuePassportToken;